===============
 URI Submodule
===============

.. autoclass:: rfc3986.uri.URIReference

.. automethod:: rfc3986.uri.URIReference.from_string

.. automethod:: rfc3986.uri.URIReference.unsplit

.. automethod:: rfc3986.uri.URIReference.resolve_with

.. automethod:: rfc3986.uri.URIReference.copy_with

.. automethod:: rfc3986.uri.URIReference.normalize

.. automethod:: rfc3986.uri.URIReference.is_absolute

.. automethod:: rfc3986.uri.URIReference.authority_info
